// A basic OpenGL program displaying a 3D house shape

#include <windows.h>
#include <gl/gl.h>
#include <gl/glu.h>
#include <gl/glut.h>
#include <iostream>
using namespace std;
#include "Trackball.h"

const int windowWidth=400;
const int windowHeight=400;

// define vertices and edges of the house
const int numVertices=10;
const int numEdges=18;
const float vertices[numVertices][3] =  {{0,0,0},{1,0,0},{0,1,0},{1,1,0},{0,0,2},
    						{1,0,2},{0,1,2},{1,1,2},{0.5f,1.5f,0},{0.5f,1.5f,2}};
const int edges[numEdges][2] = {{0,1},{1,3},{3,2},{2,0},{4,5},{5,7},{7,6},{6,4},{0,4},
					  	 	{1,5},{3,7},{2,6},{2,8},{8,3},{6,9},{9,7},{8,9}};
					  	 	
CTrackball trackball;

void handleMouseMotion(int x, int y)
{	
	trackball.tbMotion(x, y);
}

void handleMouseClick(int button, int state, int x, int y)
{
	trackball.tbMouse(button, state, x, y);
}

void handleKeyboardEvent(unsigned char key, int x, int y)
{
	trackball.tbKeyboard(key);
}

void display(void)
{
	glClear(GL_COLOR_BUFFER_BIT); 	// clear all pixels in frame buffer
	glColor3f (1.0, 0.0, 0.0);		// (red,green,blue) colour components

	glMatrixMode( GL_MODELVIEW );	// Set the view matrix ...
	glLoadIdentity();				// ... to identity.
	trackball.tbMatrix();

	glBegin(GL_LINES);
	for(int i=0;i<numEdges;i++)
	{
		glVertex3fv(vertices[edges[i][0]]);
		glVertex3fv(vertices[edges[i][1]]);
	}
	glEnd();

	glFlush ();
}

void init(void) 
{
	// select clearing color (for glClear)
	glClearColor (1.0, 1.0, 1.0, 0.0);	// RGB-value for white

	// initialize view (simple orthographic projection)
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	glOrtho(-2,2,-2,2,-3,3);
	trackball.tbInit(GLUT_LEFT_BUTTON);
}

void reshape(int width, int height ) {
	// Called at start, and whenever user resizes component
	int size = min(width, height);
	glViewport(0, 0, size, size);  // Largest possible square
	trackball.tbReshape(width, height);
}


// create a single buffered colour window
int main(int argc, char** argv)
{
	glutInit(&argc, argv);		
	glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);
	glutInitWindowSize(windowWidth, windowHeight); 
	glutInitWindowPosition(100, 100);
	glutCreateWindow("House3D");
	init ();						// initialise view
	glutMouseFunc(handleMouseClick);		// Set function to handle mouse clicks
	glutMotionFunc(handleMouseMotion);		// Set function to handle mouse motion
	glutKeyboardFunc(handleKeyboardEvent);	// Set function to handle keyboard input
	glutDisplayFunc(display);		// Set function to draw scene
	glutReshapeFunc(reshape);		// Set function called if window gets resized
	glutMainLoop();
	return 0;
}
